summaryrefslogtreecommitdiffstats
path: root/src/DotNetOpenAuth.OAuth2.AuthorizationServer/OAuth2/ChannelElements/ClientAuthenticationModuleBase.cs
diff options
context:
space:
mode:
authorAndrew Arnott <andrewarnott@gmail.com>2012-04-18 21:21:34 -0700
committerAndrew Arnott <andrewarnott@gmail.com>2012-04-18 21:21:34 -0700
commit548147a67be56f046a7d4515d61a8210d78677de (patch)
tree95ad7e72f40c60637569b30f292cd5ad9f583737 /src/DotNetOpenAuth.OAuth2.AuthorizationServer/OAuth2/ChannelElements/ClientAuthenticationModuleBase.cs
parent1cefb24fd021a0292c13d6bfd61bd81543d4dfce (diff)
downloadDotNetOpenAuth-548147a67be56f046a7d4515d61a8210d78677de.zip
DotNetOpenAuth-548147a67be56f046a7d4515d61a8210d78677de.tar.gz
DotNetOpenAuth-548147a67be56f046a7d4515d61a8210d78677de.tar.bz2
Fixed up the configuration story for OAuth 2.
Diffstat (limited to 'src/DotNetOpenAuth.OAuth2.AuthorizationServer/OAuth2/ChannelElements/ClientAuthenticationModuleBase.cs')
-rw-r--r--src/DotNetOpenAuth.OAuth2.AuthorizationServer/OAuth2/ChannelElements/ClientAuthenticationModuleBase.cs22
1 files changed, 7 insertions, 15 deletions
diff --git a/src/DotNetOpenAuth.OAuth2.AuthorizationServer/OAuth2/ChannelElements/ClientAuthenticationModuleBase.cs b/src/DotNetOpenAuth.OAuth2.AuthorizationServer/OAuth2/ChannelElements/ClientAuthenticationModuleBase.cs
index 262116d..e835e1e 100644
--- a/src/DotNetOpenAuth.OAuth2.AuthorizationServer/OAuth2/ChannelElements/ClientAuthenticationModuleBase.cs
+++ b/src/DotNetOpenAuth.OAuth2.AuthorizationServer/OAuth2/ChannelElements/ClientAuthenticationModuleBase.cs
@@ -15,32 +15,24 @@ namespace DotNetOpenAuth.OAuth2.ChannelElements {
using DotNetOpenAuth.OAuth2.Messages;
/// <summary>
- /// A convenient base class for imlementations of the <see cref="IClientAuthenticationModule"/> interface.
+ /// A base class for extensions that can read incoming messages and extract the client identifier and
+ /// possibly authentication information (like a shared secret, signed nonce, etc.)
/// </summary>
- public abstract class ClientAuthenticationModuleBase : IClientAuthenticationModule {
+ public abstract class ClientAuthenticationModule {
/// <summary>
/// Initializes a new instance of the <see cref="ClientAuthenticationModuleBase"/> class.
/// </summary>
- protected ClientAuthenticationModuleBase() {
+ protected ClientAuthenticationModule() {
}
/// <summary>
/// Attempts to extract client identification/authentication information from a message.
/// </summary>
+ /// <param name="authorizationServerHost">The authorization server host.</param>
/// <param name="requestMessage">The incoming message.</param>
/// <param name="clientIdentifier">Receives the client identifier, if one was found.</param>
/// <returns>The level of the extracted client information.</returns>
- public abstract ClientAuthenticationResult TryAuthenticateClient(AuthenticatedClientRequestBase requestMessage, out string clientIdentifier);
-
- /// <summary>
- /// Attempts to extract client identification/authentication information from a message.
- /// </summary>
- /// <param name="requestMessage">The incoming message. Always an instance of <see cref="AuthenticatedClientRequestBase"/></param>
- /// <param name="clientIdentifier">Receives the client identifier, if one was found.</param>
- /// <returns>The level of the extracted client information.</returns>
- public ClientAuthenticationResult TryAuthenticateClient(IDirectedProtocolMessage requestMessage, out string clientIdentifier) {
- return this.TryAuthenticateClient((AuthenticatedClientRequestBase)requestMessage, out clientIdentifier);
- }
+ public abstract ClientAuthenticationResult TryAuthenticateClient(IAuthorizationServerHost authorizationServerHost, AuthenticatedClientRequestBase requestMessage, out string clientIdentifier);
/// <summary>
/// Validates a client identifier and shared secret against the authoriation server's database.
@@ -15,32 +15,24 @@ namespace DotNetOpenAuth.OAuth2.ChannelElements {
/// <summary>
- /// Initializes a new instance of the <see cref="ClientAuthenticationModuleBase"/> class.
+ /// Initializes a new instance of the <see cref="ClientAuthenticationModule"/> class.
/// </summary>